@@ -1,11 +1,29 @@
 #ifndef DEBTAGS_ENVIRONMENT_H
 #define DEBTAGS_ENVIRONMENT_H
 
+/*
+ * Copyright (C) 2003--2008  Enrico Zini <enrico@debian.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #pragma interface
 
 #include <sigc++/sigc++.h>
-#include <buffy/config/Config.h>
-#include <buffy/MailFolder.h>
+#include <buffy/config/config.h>
+#include <buffy/mailfolder.h>
 
 class Environment
 {
